@@ -1,5 +1,5 @@
 package Template::Magic ;
-$VERSION = 1.39 ;
+$VERSION = 1.40 ;
 use strict ;
 use 5.006_001 ;
 
@@ -63,12 +63,7 @@ use 5.006_001 ;
                                     }
                                     @{$$s{options}}
                               }
-   ; foreach my $n qw| zone
-                       value
-                       text
-                       output
-                       post
-                     |
+   ; foreach my $n (qw| zone value text output post |)
       { $$s{$n.'_handlers'}
         &&= [ $s->_Hload( $$s{$n.'_handlers'}
                         , $n
@@ -251,6 +246,7 @@ use 5.006_001 ;
              ]
            }
            split /($$re{label})/ , $$content_ref
+  
    ; for ( my $i  = $#temp                        # find end
          ;    $i >= 0
          ;    $i --
@@ -312,7 +308,7 @@ use 5.006_001 ;
 
 ; sub DEFAULT_PRINT_HANDLERS
    { [ sub
-        { print $_[1] if defined $_[1]
+        { print "$_[1]" if defined $_[1]
         ; NEXT_HANDLER
         }
      ]
@@ -2625,4 +2621,4 @@ Thanks to I<Mark Overmeer> L<http://search.cpan.org/author/MARKOV/> which has su
 
 A special thanks to Megyaszai Sandor for his very detailed revision of the POD.
 
-=cut
\ No newline at end of file
+=cut
