@@ -1,5 +1,5 @@
 package Template::Magic::Zone ;
-$VERSION = 1.39 ;
+$VERSION = 1.40 ;
 use strict ;
 use 5.006_001 ;
 
@@ -14,11 +14,7 @@ use 5.006_001 ;
    }
 
 ; BEGIN
-   { foreach my $n qw| zone
-                       output
-                       text
-                       post
-                     |
+   { foreach my $n (qw| zone output text post |)
       { no strict 'refs'
       ; *{$n.'_process'} = sub
                             { my ($z) = @_
@@ -171,12 +167,12 @@ use 5.006_001 ;
       { $code
       }
      else
-      { no strict
+      { no strict 'refs','vars'
       ; local *S = $l.'::'.$id
       ; defined $S ?  $S
-      : defined @S ? \@S
-      : defined %S ? \%S
-      : undef
+            : @S ? \@S
+            : %S ? \%S
+            : undef
       }
    }
    
